import { ApolloProvider } from '@apollo/client'
import type { PropsWithChildren } from 'react'
import React, { Suspense } from 'react'
import { Platform, StyleSheet } from 'react-native'

import client from '@holi/api/graphql/client'
import SessionExpiryProtection from '@holi/core/components/SessionExpiryProtection'
import ErrorBoundary from '@holi/core/errors/components/ErrorBoundary'
import { NavigationContextProvider } from '@holi/core/navigation/hooks/NavigationContextProvider'
import LoginModalProvider from '@holi/core/provider/LoginModalProvider'
import PortalProvider from '@holi/core/provider/PortalProvider'
import HoliText from '@holi/ui/components/atoms/HoliText'
import SafeArea from '@holi/ui/components/atoms/SafeArea'
import { ToastProvider } from '@holi/ui/components/molecules/HoliToastProvider'
import defaultHoliTheme, { ThemeProvider } from '@holi/ui/styles/theme'

import UpdateAppModal from './components/UpdateAppModal'

const styles = StyleSheet.create({
  loadingContainer: {
    height: '100%',
    flex: 1,
    alignItems: 'center',
    justifyContent: 'flex-start',
    position: 'relative',
    marginTop: 100,
  },
})

const RootProvider = ({ children }: PropsWithChildren<unknown>) => {
  return (
    <ThemeProvider theme={defaultHoliTheme}>
      {/* Necessary for loading e.g. translations on mobile */}
      {/* TODO: replace with proper loading indicator */}
      <Suspense
        fallback={
          <SafeArea style={styles.loadingContainer}>
            <HoliText style={{ textAlign: 'center' }}>Loading...</HoliText>
          </SafeArea>
        }
      >
        <ErrorBoundary>
          <ApolloProvider client={client}>
            <ToastProvider>
              <PortalProvider>
                <NavigationContextProvider>
                  <SessionExpiryProtection>
                    {Platform.OS !== 'web' ? <UpdateAppModal /> : null}
                    <LoginModalProvider>{children}</LoginModalProvider>
                  </SessionExpiryProtection>
                </NavigationContextProvider>
              </PortalProvider>
            </ToastProvider>
          </ApolloProvider>
        </ErrorBoundary>
      </Suspense>
    </ThemeProvider>
  )
}

export default RootProvider
